import React, { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';
import { showNotification } from '../../store/notification.slice';
import { fetchKnowledgeBases } from '../../store/knowledgeBase/knowledgeBase.thunks';
import SvgIcon from '../../components/SvgIcon';

export default function NewChat() {
    const navigate = useNavigate();
    const dispatch = useDispatch();

    // 从 Redux store 获取知识库数据 - 使用新的状态结构
    const knowledgeBases = useSelector((state) => state.knowledgeBase.knowledgeBases || []);
    const isLoading = useSelector((state) => state.knowledgeBase.loading);
    const error = useSelector((state) => state.knowledgeBase.error);

    // 获取知识库列表
    useEffect(() => {
        dispatch(fetchKnowledgeBases({ page: 1, page_size: 50 }));
    }, [dispatch]);

    // 监听错误状态
    useEffect(() => {
        if (error) {
            dispatch(
                showNotification({
                    message: `获取知识库列表失败: ${error.message || error}`,
                    type: 'danger',
                })
            );
        }
    }, [error, dispatch]);

    // 过滤出有 can_read 权限的知识库
    const readableKnowledgeBases = knowledgeBases.filter((kb) => kb.permissions && kb.permissions.can_read === true);

    const handleSelectKnowledgeBase = (knowledgeBaseId) => {
        // 创建新聊天并导航到聊天页面
        navigate(`/chat/${knowledgeBaseId}`);
    };

    // 渲染加载状态
    if (isLoading) {
        return (
            <div className='container-fluid px-4 py-5 text-center'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
            </div>
        );
    }

    return (
        <div className='container-fluid px-4 py-5'>
            <h4 className='mb-4'>选择知识库开始聊天</h4>
            <div className='row row-cols-1 row-cols-md-2 row-cols-lg-3 g-4 justify-content-center'>
                {readableKnowledgeBases.length > 0 ? (
                    readableKnowledgeBases.map((kb) => (
                        <div key={kb.id} className='col'>
                            <div
                                className='card h-100 shadow-sm border-0 cursor-pointer'
                                onClick={() => handleSelectKnowledgeBase(kb.id)}
                            >
                                <div className='card-body'>
                                    <h5 className='card-title'>{kb.name}</h5>
                                    <p className='card-text text-muted'>{kb.desc || kb.description || ''}</p>
                                    <div className='text-muted small d-flex align-items-center gap-2'>
                                        <span className='d-flex align-items-center gap-1'>
                                            <SvgIcon className='file' />
                                            {kb.document_count} 文档
                                        </span>
                                        <span className='d-flex align-items-center gap-1'>
                                            <SvgIcon className='clock' />
                                            {new Date(kb.create_time).toLocaleDateString()}
                                        </span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    ))
                ) : (
                    <div className='col-12'>
                        <div className='alert alert-warning'>暂无可访问的知识库，请先申请知识库访问权限</div>
                    </div>
                )}
            </div>
        </div>
    );
}
